@@ -5,7 +5,7 @@
 #' \code{calculate_features} computes several features associated with a
 #' categorical time series or between a categorical and a real-valued time series
 #'
-#' @param series An object of type \code{tsibble} (see R package \code{tsibble}), whose column named Values
+#' @param series An object of type \code{tsibble} (see R package \code{tsibble}), whose column named Value
 #' contains the values of the corresponding CTS. This column must be of class \code{factor} and its levels
 #' must be determined by the range of the CTS.
 #' @param n_series A real-valued time series.
@@ -105,7 +105,7 @@
 
 calculate_features <- function(series, n_series = NULL, lag = 1, type = NULL) {
 
-  check_cts(series$Value)
+  check_cts(series)
   series_length <- length(series$Value) # Series length
   categories <- levels(series$Value)
   n_cat <- length(categories) # Number of categories in the dataset
