@@ -4,7 +4,7 @@
 #'
 #' \code{calculate_motifs} computes the motifs of a categorical time series
 #'
-#' @param series An object of type \code{tsibble} (see R package \code{tsibble}), whose column named Values
+#' @param series An object of type \code{tsibble} (see R package \code{tsibble}), whose column named Value
 #' contains the values of the corresponding CTS. This column must be of class \code{factor} and its levels
 #' must be determined by the range of the CTS.
 #' @param motif_length The length of the motif.
@@ -34,7 +34,7 @@
 calculate_motifs <- function(series, motif_length){
 
 
-  check_cts(series$Value)
+  check_cts(series)
   series_length <- length(series$Value) # Series length
   categories <- levels(series$Value)
   n_cat <- length(categories) # Number of categories in the dataset
