@@ -22,7 +22,7 @@ check_cts <- function(X) {
 
   # The element can not contain NA entries
 
-  check_nas <- sum(is.na(X))
+  check_nas <- sum(is.na(X$Value))
 
   if (sum(check_nas) != 0) {
 
@@ -30,4 +30,13 @@ check_cts <- function(X) {
 
   }
 
+  check_tsibble <- tsibble::is_tsibble(X)
+
+
+  if (!check_tsibble) {
+
+    stop('Please, give a tsibble object as input')
+
+  }
+
 }
