@@ -5,7 +5,7 @@
 #' \code{conditional_probabilities} returns a matrix with the conditional
 #' probabilities of a categorical time series
 #'
-#' @param series An object of type \code{tsibble} (see R package \code{tsibble}), whose column named Values
+#' @param series An object of type \code{tsibble} (see R package \code{tsibble}), whose column named Value
 #' contains the values of the corresponding CTS. This column must be of class \code{factor} and its levels
 #' must be determined by the range of the CTS.
 #' @param lag The considered lag (default is 1).
@@ -33,7 +33,7 @@
 
 conditional_probabilities <- function(series, lag = 1) {
 
-  check_cts(series$Value)
+  check_cts(series)
   n_cat <- length(levels(series$Value))
   matrix_probs <- matrix(0, n_cat, n_cat)
 
