@@ -5,7 +5,7 @@
 #' \code{marginal_probabilities} returns a vector with the marginal
 #' probabilities of a categorical time series
 #'
-#' @param series An object of type \code{tsibble} (see R package \code{tsibble}), whose column named Values
+#' @param series An object of type \code{tsibble} (see R package \code{tsibble}), whose column named Value
 #' contains the values of the corresponding CTS. This column must be of class \code{factor} and its levels
 #' must be determined by the range of the CTS.
 #' @return A vector with the marginal probabilities.
@@ -31,7 +31,7 @@
 
 marginal_probabilities <- function(series) {
 
-  check_cts(series$Value)
+  check_cts(series)
   series_length <- length(series$Value) # Series length
   categories <- levels(series$Value)
   n_cat <- length(categories) # Number of categories in the dataset
