@@ -5,7 +5,7 @@
 #' \code{plot_cramer} constructs a serial dependence plot of a categorical
 #' time series based on Cramer's vi
 #'
-#' @param series An object of type \code{tsibble} (see R package \code{tsibble}), whose column named Values
+#' @param series An object of type \code{tsibble} (see R package \code{tsibble}), whose column named Value
 #' contains the values of the corresponding CTS. This column must be of class \code{factor} and its levels
 #' must be determined by the range of the CTS.
 #' @param max_lag The maximum lag represented in the plot (default is 10).
@@ -45,7 +45,7 @@ plot_cramer <- function(series, max_lag = 10, alpha = 0.05, plot = TRUE,
                             title = 'Serial dependence plot', bar_width = 0.12,...) {
 
   x <- y <- NULL
-  check_cts(series$Value)
+  check_cts(series)
   series_length <- length(series$Value) # Series length
   categories <- levels(series$Value)
   n_cat <- length(categories) # Number of categories in the dataset
