@@ -4,7 +4,7 @@
 #'
 #' \code{plot_cts} constructs a categorical time series plot
 #'
-#' @param series An object of type \code{tsibble} (see R package \code{tsibble}), whose column named Values
+#' @param series An object of type \code{tsibble} (see R package \code{tsibble}), whose column named Value
 #' contains the values of the corresponding CTS. This column must be of class \code{factor} and its levels
 #' must be determined by the range of the CTS.
 #' @param title The title of the graph.
@@ -29,7 +29,7 @@
 plot_cts <- function(series, title = 'Time series plot') {
 
   x <- y <- NULL
-  check_cts(series$Value)
+  check_cts(series)
   series_length <- length(series$Value) # Series length
   categories <- levels(series$Value)
   n_cat <- length(categories) # Number of categories in the dataset
