@@ -6,7 +6,7 @@
 #' \code{plot_ifsct} constructs the IFS circle transformation of
 #' a categorical time series.
 #'
-#' @param series An object of type \code{tsibble} (see R package \code{tsibble}), whose column named Values
+#' @param series An object of type \code{tsibble} (see R package \code{tsibble}), whose column named Value
 #' contains the values of the corresponding CTS. This column must be of class \code{factor} and its levels
 #' must be determined by the range of the CTS.
 #' @param alpha Parameter alpha in the circle transformation.
@@ -35,7 +35,7 @@ plot_ifsct <- function(series, alpha, beta,
                                       title = 'IFS circle transformation',...) {
 
   x <- y <- z <- NULL
-  check_cts(series$Value)
+  check_cts(series)
   series_length <- length(series$Value) # Series length
   categories <- levels(series$Value)
   n_cat <- length(categories) # Number of categories in the dataset
